Unified Judicial System of Pennsylvania: Supreme Court Opinions

http://www.pacourts.us/assets/rss/SupremeOpinionsRss.ashx Unified Judicial System of Pennsylvania: Supreme Court Opinions Tue, 29 Jul 2014 04:00:00 GMT en-us Commonwealth v. Mickle, V., Pet. - No. 83 EAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/83EAL2014 - 1018909802459175.pdf http://www.pacourts.us/assets/opinions/Supreme/out/83EAL2014 - 1018909802459175.pdf http://www.pacourts.us/assets/opinions/Supreme/out/83EAL2014 - 1018909802459175.pdf Tue, 29 Jul 2014 04:00:00 GMT Per Curiam Commonweatlh v. Garwood, A, Pet. - No. 74 EAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/74EAL2014 - 1018909762459161.pdf http://www.pacourts.us/assets/opinions/Supreme/out/74EAL2014 - 1018909762459161.pdf http://www.pacourts.us/assets/opinions/Supreme/out/74EAL2014 - 1018909762459161.pdf Tue, 29 Jul 2014 04:00:00 GMT Per Curiam Commonwealth. v. Al-Amin, M., Pet. - No. 54 EAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/54EAL2014 - 1018909732459144.pdf http://www.pacourts.us/assets/opinions/Supreme/out/54EAL2014 - 1018909732459144.pdf http://www.pacourts.us/assets/opinions/Supreme/out/54EAL2014 - 1018909732459144.pdf Tue, 29 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. Miller, H., Pet. - No. 102 EAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/102EAL2014 - 1018899082456008.pdf http://www.pacourts.us/assets/opinions/Supreme/out/102EAL2014 - 1018899082456008.pdf http://www.pacourts.us/assets/opinions/Supreme/out/102EAL2014 - 1018899082456008.pdf Tue, 29 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. Rosser, Q., Pet. - No. 98 EAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/98EAL2014 - 1018899062456003.pdf http://www.pacourts.us/assets/opinions/Supreme/out/98EAL2014 - 1018899062456003.pdf http://www.pacourts.us/assets/opinions/Supreme/out/98EAL2014 - 1018899062456003.pdf Tue, 29 Jul 2014 04:00:00 GMT Per Curiam Snizavich, A., Pet., v. Rohm and Haas Company - No. 88 EAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/88EAL2014 - 1018899032455999.pdf http://www.pacourts.us/assets/opinions/Supreme/out/88EAL2014 - 1018899032455999.pdf http://www.pacourts.us/assets/opinions/Supreme/out/88EAL2014 - 1018899032455999.pdf Tue, 29 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. Cobbs, D., Pet. - No. 592 WAL 2013 http://www.pacourts.us/assets/opinions/Supreme/out/592WAL2013 - 1018899112456019.pdf http://www.pacourts.us/assets/opinions/Supreme/out/592WAL2013 - 1018899112456019.pdf http://www.pacourts.us/assets/opinions/Supreme/out/592WAL2013 - 1018899112456019.pdf Tue, 29 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. Evans, J., Pet. - No. 110 WAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/110WAL2014 - 1018909892459215.pdf http://www.pacourts.us/assets/opinions/Supreme/out/110WAL2014 - 1018909892459215.pdf http://www.pacourts.us/assets/opinions/Supreme/out/110WAL2014 - 1018909892459215.pdf Tue, 29 Jul 2014 04:00:00 GMT Per Curiam Amato, R. v. Kipp, C., Pet - No. 65 MM 2014 http://www.pacourts.us/assets/opinions/Supreme/out/65MM2014 - 1018901732456845.pdf http://www.pacourts.us/assets/opinions/Supreme/out/65MM2014 - 1018901732456845.pdf http://www.pacourts.us/assets/opinions/Supreme/out/65MM2014 - 1018901732456845.pdf Tue, 29 Jul 2014 04:00:00 GMT Per Curiam Oliver, A., Pet. v. Montgomery Co. CCP - No. 58 MM 2014 http://www.pacourts.us/assets/opinions/Supreme/out/58MM2014 - 1018901452456752.pdf http://www.pacourts.us/assets/opinions/Supreme/out/58MM2014 - 1018901452456752.pdf http://www.pacourts.us/assets/opinions/Supreme/out/58MM2014 - 1018901452456752.pdf Tue, 29 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. Carr, JR., Pet - No. 122 MAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/122MAL2014 - 1018909902459237.pdf http://www.pacourts.us/assets/opinions/Supreme/out/122MAL2014 - 1018909902459237.pdf http://www.pacourts.us/assets/opinions/Supreme/out/122MAL2014 - 1018909902459237.pdf Tue, 29 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. Torres, A., Pet - No. 165 MAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/165MAL2014 - 1018899102456015.pdf http://www.pacourts.us/assets/opinions/Supreme/out/165MAL2014 - 1018899102456015.pdf http://www.pacourts.us/assets/opinions/Supreme/out/165MAL2014 - 1018899102456015.pdf Tue, 29 Jul 2014 04:00:00 GMT Per Curiam In the Matter of: Edward Benjamin Weisbein - No. 1395 DD3 http://www.pacourts.us/assets/opinions/Supreme/out/1395DD3 - 1018895942454799.pdf http://www.pacourts.us/assets/opinions/Supreme/out/1395DD3 - 1018895942454799.pdf http://www.pacourts.us/assets/opinions/Supreme/out/1395DD3 - 1018895942454799.pdf Mon, 28 Jul 2014 04:00:00 GMT Per Curiam ODC, Pet. v. Brett B. Weinstein - No. 2038 DD3 http://www.pacourts.us/assets/opinions/Supreme/out/2038DD3 - 1018897012455103.pdf http://www.pacourts.us/assets/opinions/Supreme/out/2038DD3 - 1018897012455103.pdf http://www.pacourts.us/assets/opinions/Supreme/out/2038DD3 - 1018897012455103.pdf Mon, 28 Jul 2014 04:00:00 GMT Per Curiam In Re: Order Amending Rules 120, 163, 167, 170, 172, 370, 408, 409, and 1120, and Adopting New Rule 173 of the Pennsylvania Rules of Juvenile Court Procedure, No. 641 Supreme Court Rules Docket http://www.pacourts.us/assets/opinions/Supreme/out/641spct.pdf http://www.pacourts.us/assets/opinions/Supreme/out/641spct.pdf http://www.pacourts.us/assets/opinions/Supreme/out/641spct.pdf Mon, 28 Jul 2014 04:00:00 GMT per curiam In Re: Order Amending Rules 120, 163, 167, 170, 172, 370, 408, 409, and 1120, and Adopting New Rule 173 of the Pennsylvania Rules of Juvenile Court Procedure, No. 641 Supreme Court Rules Docket http://www.pacourts.us/assets/opinions/Supreme/out/641spct-attach.pdf http://www.pacourts.us/assets/opinions/Supreme/out/641spct-attach.pdf http://www.pacourts.us/assets/opinions/Supreme/out/641spct-attach.pdf Mon, 28 Jul 2014 04:00:00 GMT per curiam In Re: Order Amending Rules 120, 163, 167, 170, 172, 370, 408, 409, and 1120, and Adopting New Rule 173 of the Pennsylvania Rules of Juvenile Court Procedure, No. 641 Supreme Court Rules Docket http://www.pacourts.us/assets/opinions/Supreme/out/641spct-rpt.pdf http://www.pacourts.us/assets/opinions/Supreme/out/641spct-rpt.pdf http://www.pacourts.us/assets/opinions/Supreme/out/641spct-rpt.pdf Mon, 28 Jul 2014 04:00:00 GMT per curiam Mustafa, A., Pet v. Riscigno, C., et al - No. 137 MAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/137MAL2014 - 1018883482451153.pdf http://www.pacourts.us/assets/opinions/Supreme/out/137MAL2014 - 1018883482451153.pdf http://www.pacourts.us/assets/opinions/Supreme/out/137MAL2014 - 1018883482451153.pdf Mon, 28 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. Snyder, R., Pet - No. 160 MAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/160MAL2014 - 1018883492451163.pdf http://www.pacourts.us/assets/opinions/Supreme/out/160MAL2014 - 1018883492451163.pdf http://www.pacourts.us/assets/opinions/Supreme/out/160MAL2014 - 1018883492451163.pdf Mon, 28 Jul 2014 04:00:00 GMT Per Curiam Miller, S., Pet v. Connor, G. - No. 172 MAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/172MAL2014 - 1018883502451168.pdf http://www.pacourts.us/assets/opinions/Supreme/out/172MAL2014 - 1018883502451168.pdf http://www.pacourts.us/assets/opinions/Supreme/out/172MAL2014 - 1018883502451168.pdf Mon, 28 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. Wholaver E., Pet. - No. 139 EAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/139EAL2014 - 1018883462451147.pdf http://www.pacourts.us/assets/opinions/Supreme/out/139EAL2014 - 1018883462451147.pdf http://www.pacourts.us/assets/opinions/Supreme/out/139EAL2014 - 1018883462451147.pdf Mon, 28 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. Turner, W., Pet. - No. 119 EAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/119EAL2014 - 1018883422451142.pdf http://www.pacourts.us/assets/opinions/Supreme/out/119EAL2014 - 1018883422451142.pdf http://www.pacourts.us/assets/opinions/Supreme/out/119EAL2014 - 1018883422451142.pdf Mon, 28 Jul 2014 04:00:00 GMT Per Curiam Johnson, G., Pet. v. Phila Housing Auth - No. 122 EAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/122EAL2014 - 1018883442451144.pdf http://www.pacourts.us/assets/opinions/Supreme/out/122EAL2014 - 1018883442451144.pdf http://www.pacourts.us/assets/opinions/Supreme/out/122EAL2014 - 1018883442451144.pdf Mon, 28 Jul 2014 04:00:00 GMT Per Curiam Johnson, G., Pet. v. Phila Housing Auth - No. 123 EAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/123EAL2014 - 1018883452451144.pdf http://www.pacourts.us/assets/opinions/Supreme/out/123EAL2014 - 1018883452451144.pdf http://www.pacourts.us/assets/opinions/Supreme/out/123EAL2014 - 1018883452451144.pdf Mon, 28 Jul 2014 04:00:00 GMT Per Curiam Elliott, W., Pet v. Divine Providence Village - No. 52 MM 2014 http://www.pacourts.us/assets/opinions/Supreme/out/52MM2014 - 1018888962452697.pdf http://www.pacourts.us/assets/opinions/Supreme/out/52MM2014 - 1018888962452697.pdf http://www.pacourts.us/assets/opinions/Supreme/out/52MM2014 - 1018888962452697.pdf Mon, 28 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. Vu, N., Pet. - No. 104 EAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/104EAL2014 - 1018883412451138.pdf http://www.pacourts.us/assets/opinions/Supreme/out/104EAL2014 - 1018883412451138.pdf http://www.pacourts.us/assets/opinions/Supreme/out/104EAL2014 - 1018883412451138.pdf Mon, 28 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. Burnett, M., Pet - No. 68 MM 2014 http://www.pacourts.us/assets/opinions/Supreme/out/68MM2014 - 1018886802452035.pdf http://www.pacourts.us/assets/opinions/Supreme/out/68MM2014 - 1018886802452035.pdf http://www.pacourts.us/assets/opinions/Supreme/out/68MM2014 - 1018886802452035.pdf Mon, 28 Jul 2014 04:00:00 GMT Per Curiam Harper, M., Pet. v. C.F.C.F - No. 53 EM 2014 http://www.pacourts.us/assets/opinions/Supreme/out/53EM2014 - 1018891622453969.pdf http://www.pacourts.us/assets/opinions/Supreme/out/53EM2014 - 1018891622453969.pdf http://www.pacourts.us/assets/opinions/Supreme/out/53EM2014 - 1018891622453969.pdf Mon, 28 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. Burnett, M., Pet - No. 59 MM 2014 http://www.pacourts.us/assets/opinions/Supreme/out/59MM2014 - 1018886702451999.pdf http://www.pacourts.us/assets/opinions/Supreme/out/59MM2014 - 1018886702451999.pdf http://www.pacourts.us/assets/opinions/Supreme/out/59MM2014 - 1018886702451999.pdf Mon, 28 Jul 2014 04:00:00 GMT Per Curiam Pitts, D., Pet. v. Hon. Dembe, P. - No. 57 EM 2014 http://www.pacourts.us/assets/opinions/Supreme/out/57EM2014 - 1018891792453447.pdf http://www.pacourts.us/assets/opinions/Supreme/out/57EM2014 - 1018891792453447.pdf http://www.pacourts.us/assets/opinions/Supreme/out/57EM2014 - 1018891792453447.pdf Mon, 28 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. Kokinda, J., Pet. - No. 76 MM 2014 http://www.pacourts.us/assets/opinions/Supreme/out/76MM2014 - 1018886232451840.pdf http://www.pacourts.us/assets/opinions/Supreme/out/76MM2014 - 1018886232451840.pdf http://www.pacourts.us/assets/opinions/Supreme/out/76MM2014 - 1018886232451840.pdf Mon, 28 Jul 2014 04:00:00 GMT Per Curiam Gay, W., Pet. v. Bickle, T. - No. 58 EM 2014 http://www.pacourts.us/assets/opinions/Supreme/out/58EM2014 - 1018892082453501.pdf http://www.pacourts.us/assets/opinions/Supreme/out/58EM2014 - 1018892082453501.pdf http://www.pacourts.us/assets/opinions/Supreme/out/58EM2014 - 1018892082453501.pdf Mon, 28 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. Kokinda, J., Pet - No. 57 MM 2014 http://www.pacourts.us/assets/opinions/Supreme/out/57MM2014 - 1018886582451937.pdf http://www.pacourts.us/assets/opinions/Supreme/out/57MM2014 - 1018886582451937.pdf http://www.pacourts.us/assets/opinions/Supreme/out/57MM2014 - 1018886582451937.pdf Mon, 28 Jul 2014 04:00:00 GMT Per Curiam Braxton, C., Pet. v. Ct. Com. Pl. - No. 69 EM 2014 http://www.pacourts.us/assets/opinions/Supreme/out/69EM2014 - 1018892812453750.pdf http://www.pacourts.us/assets/opinions/Supreme/out/69EM2014 - 1018892812453750.pdf http://www.pacourts.us/assets/opinions/Supreme/out/69EM2014 - 1018892812453750.pdf Mon, 28 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. McPherron, P., Pet - No. 53 MM 2014 http://www.pacourts.us/assets/opinions/Supreme/out/53MM2014 - 1018886602451945.pdf http://www.pacourts.us/assets/opinions/Supreme/out/53MM2014 - 1018886602451945.pdf http://www.pacourts.us/assets/opinions/Supreme/out/53MM2014 - 1018886602451945.pdf Mon, 28 Jul 2014 04:00:00 GMT Per Curiam HACP v. Karpiel, H., Pet - No. 166 WAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/166WAL2014 - 1018883472451150.pdf http://www.pacourts.us/assets/opinions/Supreme/out/166WAL2014 - 1018883472451150.pdf http://www.pacourts.us/assets/opinions/Supreme/out/166WAL2014 - 1018883472451150.pdf Mon, 28 Jul 2014 04:00:00 GMT Per Curiam Maddrey, D., Pet. v. Giroux, N. - No. 50 EM 2014 http://www.pacourts.us/assets/opinions/Supreme/out/50EM2014 - 1018873542448769.pdf http://www.pacourts.us/assets/opinions/Supreme/out/50EM2014 - 1018873542448769.pdf http://www.pacourts.us/assets/opinions/Supreme/out/50EM2014 - 1018873542448769.pdf Fri, 25 Jul 2014 04:00:00 GMT Per Curiam Brown, D., Pet v. Ct. Com. Pl. of Phila., Cty. - No. 59 EM 2014 http://www.pacourts.us/assets/opinions/Supreme/out/59EM2014 - 1018872212448476.pdf http://www.pacourts.us/assets/opinions/Supreme/out/59EM2014 - 1018872212448476.pdf http://www.pacourts.us/assets/opinions/Supreme/out/59EM2014 - 1018872212448476.pdf Fri, 25 Jul 2014 04:00:00 GMT Per Curiam Wilkins, G., Pet v. Cumberland County DA - No. 44 MM 2014 http://www.pacourts.us/assets/opinions/Supreme/out/44MM2014 - 1018868442447343.pdf http://www.pacourts.us/assets/opinions/Supreme/out/44MM2014 - 1018868442447343.pdf http://www.pacourts.us/assets/opinions/Supreme/out/44MM2014 - 1018868442447343.pdf Fri, 25 Jul 2014 04:00:00 GMT Per Curiam Wilkins, G., Pet. v. Dauphin Co. DA - No. 60 MM 2014 http://www.pacourts.us/assets/opinions/Supreme/out/60MM2014 - 1018868822447420.pdf http://www.pacourts.us/assets/opinions/Supreme/out/60MM2014 - 1018868822447420.pdf http://www.pacourts.us/assets/opinions/Supreme/out/60MM2014 - 1018868822447420.pdf Fri, 25 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. Walker, A., Pet. - No. 108 EAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/108EAL2014 - 1018867162447111.pdf http://www.pacourts.us/assets/opinions/Supreme/out/108EAL2014 - 1018867162447111.pdf http://www.pacourts.us/assets/opinions/Supreme/out/108EAL2014 - 1018867162447111.pdf Fri, 25 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. Zachmann, T., Pet. - No. 135 EAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/135EAL2014 - 1018867172447120.pdf http://www.pacourts.us/assets/opinions/Supreme/out/135EAL2014 - 1018867172447120.pdf http://www.pacourts.us/assets/opinions/Supreme/out/135EAL2014 - 1018867172447120.pdf Fri, 25 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. Mackie, E. Pet. - No. 158 EAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/158EAL2014 - 1018867202447126.pdf http://www.pacourts.us/assets/opinions/Supreme/out/158EAL2014 - 1018867202447126.pdf http://www.pacourts.us/assets/opinions/Supreme/out/158EAL2014 - 1018867202447126.pdf Fri, 25 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. D'Oliveira, Y., Pet. - No. 75 EAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/75EAL2014 - 1018867092447093.pdf http://www.pacourts.us/assets/opinions/Supreme/out/75EAL2014 - 1018867092447093.pdf http://www.pacourts.us/assets/opinions/Supreme/out/75EAL2014 - 1018867092447093.pdf Fri, 25 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. Christie, M., Pet. - No. 97 EAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/97EAL2014 - 1018867132447105.pdf http://www.pacourts.us/assets/opinions/Supreme/out/97EAL2014 - 1018867132447105.pdf http://www.pacourts.us/assets/opinions/Supreme/out/97EAL2014 - 1018867132447105.pdf Fri, 25 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. Johnson, J., Pet. - No. 52 EM 2014 http://www.pacourts.us/assets/opinions/Supreme/out/52EM2014 - 1018870512447947.pdf http://www.pacourts.us/assets/opinions/Supreme/out/52EM2014 - 1018870512447947.pdf http://www.pacourts.us/assets/opinions/Supreme/out/52EM2014 - 1018870512447947.pdf Fri, 25 Jul 2014 04:00:00 GMT Per Curiam Fischetti, K. v. Fischetti, Jr., A., Pet - No. 106 MAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/106MAL2014 - 1018867372447153.pdf http://www.pacourts.us/assets/opinions/Supreme/out/106MAL2014 - 1018867372447153.pdf http://www.pacourts.us/assets/opinions/Supreme/out/106MAL2014 - 1018867372447153.pdf Fri, 25 Jul 2014 04:00:00 GMT Per Curiam Anderson, J., Pet. v. Ct. Com. Pl., et al. - No. 54 EM 2014 http://www.pacourts.us/assets/opinions/Supreme/out/54EM2014 - 1018870922448100.pdf http://www.pacourts.us/assets/opinions/Supreme/out/54EM2014 - 1018870922448100.pdf http://www.pacourts.us/assets/opinions/Supreme/out/54EM2014 - 1018870922448100.pdf Fri, 25 Jul 2014 04:00:00 GMT Per Curiam Holmes, T., Pet. v. C.C.P. Phila. Cty. - No. 55 EM 2014 http://www.pacourts.us/assets/opinions/Supreme/out/55EM2014 - 1018871542448328.pdf http://www.pacourts.us/assets/opinions/Supreme/out/55EM2014 - 1018871542448328.pdf http://www.pacourts.us/assets/opinions/Supreme/out/55EM2014 - 1018871542448328.pdf Fri, 25 Jul 2014 04:00:00 GMT Per Curiam Commonwealth v. Schultz, W., Pet. - No. 180 MAL 2014 http://www.pacourts.us/assets/opinions/Supreme/out/180MAL2014 - 1018867382447168.pdf http://www.pacourts.us/assets/opinions/Supreme/out/180MAL2014 - 1018867382447168.pdf http://www.pacourts.us/assets/opinions/Supreme/out/180MAL2014 - 1018867382447168.pdf Fri, 25 Jul 2014 04:00:00 GMT Per Curiam